# Ubuntu Testing Automation Harness
# Copyright 2012 Canonical Ltd.

# This program is free software: you can redistribute it and/or modify it
# under the terms of the GNU General Public License version 3, as published
# by the Free Software Foundation.

# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranties of
# MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR
# PURPOSE.  See the GNU General Public License for more details.

# You should have received a copy of the GNU General Public License along
# with this program.  If not, see <http://www.gnu.org/licenses/>.

"""Module provides paths to the utah client debs needed for install."""

import apt.cache
import os

from glob import glob

from utah.config import config
from utah.provisioning.exceptions import UTAHProvisioningException


def _utah_deb(deb):
    utah_version = apt.cache.Cache()['utah'].installed.version
    if utah_version is None:
        raise UTAHProvisioningException("UTAH package isn't installed")

    basename = ('utah-{}_{}_all.deb'.format(deb, utah_version))
    path = os.path.join(config.packagedir, basename)
    if not os.path.isfile(path):
        raise UTAHProvisioningException(
            'UTAH {} binary package file not found in {}'.format(path, deb))
    return path


def _schema_deb():
    debpath = config.packagedir
    deb_file_glob = os.path.join(debpath, 'python-jsonschema_*_all.deb')
    deb_files = glob(deb_file_glob)
    if not deb_files:
        msg = 'python-jsonschema package file not found in {}'.format(debpath)
        raise UTAHProvisioningException(msg)
    deb_files.sort()
    return deb_files[-1]


def get_client_debs():
    """Return paths to all .debs required to install the utah-client.

    :returns: Local paths to deb files
    :rtype: list
    :raises UTAHProvisioningException: When package(s) can't be found

    """
    return [_schema_deb(), _utah_deb('common'), _utah_deb('client')]
